pub struct WhiteNoise {
pub mean: f64,
pub sigma: f64,
}Expand description
White noise is an uncorrelated random variable.
Fields
mean: f64Mean value of this white noise
sigma: f64Process noise as a one-sigma of the Normal distribution.
Implementations
Sourceimpl WhiteNoise
impl WhiteNoise
Sourcepub fn new(
process_noise: f64,
integration_time: Duration,
) -> Result<Self, ConfigError>
pub fn new( process_noise: f64, integration_time: Duration, ) -> Result<Self, ConfigError>
Initializes a new random walk stochastic noise model from the process noise and the integration time. This will compute the process noise per second automatically.
Sourcepub fn constant_white_noise(process_noise: f64) -> Self
pub fn constant_white_noise(process_noise: f64) -> Self
Initializes a new random walk stochastic noise model from the provided process noise, assuming that the noise level is fixed regardless of the integration time.
pub fn from_pr_n0(pr_n0: f64, bandwidth_hz: f64) -> Self